@@ -25,14 +25,13 @@ class CreateMonitorGroupRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'CreateMonitorGroup','cms')
 		self.set_method('POST')
 
-	def get_ContactGroups(self):
+	def get_ContactGroups(self): # String
 		return self.get_query_params().get('ContactGroups')
 
-	def set_ContactGroups(self,ContactGroups):
-		self.add_query_param('ContactGroups',ContactGroups)
-
-	def get_GroupName(self):
+	def set_ContactGroups(self, ContactGroups):  # String
+		self.add_query_param('ContactGroups', ContactGroups)
+	def get_GroupName(self): # String
 		return self.get_query_params().get('GroupName')
 
-	def set_GroupName(self,GroupName):
-		self.add_query_param('GroupName',GroupName)
\ No newline at end of file
+	def set_GroupName(self, GroupName):  # String
+		self.add_query_param('GroupName', GroupName)
