@@ -25,8 +25,8 @@ class DeleteMetricRuleTemplateRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DeleteMetricRuleTemplate','cms')
 		self.set_method('POST')
 
-	def get_TemplateId(self):
+	def get_TemplateId(self): # String
 		return self.get_query_params().get('TemplateId')
 
-	def set_TemplateId(self,TemplateId):
-		self.add_query_param('TemplateId',TemplateId)
\ No newline at end of file
+	def set_TemplateId(self, TemplateId):  # String
+		self.add_query_param('TemplateId', TemplateId)
