@@ -25,14 +25,13 @@ class DeleteMonitorGroupNotifyPolicyRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DeleteMonitorGroupNotifyPolicy','cms')
 		self.set_method('POST')
 
-	def get_PolicyType(self):
+	def get_PolicyType(self): # String
 		return self.get_query_params().get('PolicyType')
 
-	def set_PolicyType(self,PolicyType):
-		self.add_query_param('PolicyType',PolicyType)
-
-	def get_GroupId(self):
+	def set_PolicyType(self, PolicyType):  # String
+		self.add_query_param('PolicyType', PolicyType)
+	def get_GroupId(self): # String
 		return self.get_query_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
\ No newline at end of file
+	def set_GroupId(self, GroupId):  # String
+		self.add_query_param('GroupId', GroupId)
