@@ -23,10 +23,10 @@ class DescribeActiveMetricRuleListRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeActiveMetricRuleList','cms')
-		self.set_method('GET')
+		self.set_method('POST')
 
-	def get_Product(self):
+	def get_Product(self): # String
 		return self.get_query_params().get('Product')
 
-	def set_Product(self,Product):
-		self.add_query_param('Product',Product)
\ No newline at end of file
+	def set_Product(self, Product):  # String
+		self.add_query_param('Product', Product)
