@@ -23,9 +23,15 @@ class DescribeEventRuleAttributeRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeEventRuleAttribute','cms')
+		self.set_method('POST')
 
-	def get_RuleName(self):
+	def get_RuleName(self): # String
 		return self.get_query_params().get('RuleName')
 
-	def set_RuleName(self,RuleName):
-		self.add_query_param('RuleName',RuleName)
\ No newline at end of file
+	def set_RuleName(self, RuleName):  # String
+		self.add_query_param('RuleName', RuleName)
+	def get_SilenceTime(self): # String
+		return self.get_query_params().get('SilenceTime')
+
+	def set_SilenceTime(self, SilenceTime):  # String
+		self.add_query_param('SilenceTime', SilenceTime)
