@@ -25,8 +25,8 @@ class DescribeMetricRuleTargetsRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMetricRuleTargets','cms')
 		self.set_method('POST')
 
-	def get_RuleId(self):
+	def get_RuleId(self): # String
 		return self.get_query_params().get('RuleId')
 
-	def set_RuleId(self,RuleId):
-		self.add_query_param('RuleId',RuleId)
\ No newline at end of file
+	def set_RuleId(self, RuleId):  # String
+		self.add_query_param('RuleId', RuleId)
