@@ -25,8 +25,8 @@ class DescribeMonitorGroupDynamicRulesRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMonitorGroupDynamicRules','cms')
 		self.set_method('POST')
 
-	def get_GroupId(self):
+	def get_GroupId(self): # Long
 		return self.get_query_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
\ No newline at end of file
+	def set_GroupId(self, GroupId):  # Long
+		self.add_query_param('GroupId', GroupId)
