@@ -25,8 +25,13 @@ class DescribeMonitoringAgentStatusesRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMonitoringAgentStatuses','cms')
 		self.set_method('POST')
 
-	def get_InstanceIds(self):
+	def get_HostAvailabilityTaskId(self): # String
+		return self.get_query_params().get('HostAvailabilityTaskId')
+
+	def set_HostAvailabilityTaskId(self, HostAvailabilityTaskId):  # String
+		self.add_query_param('HostAvailabilityTaskId', HostAvailabilityTaskId)
+	def get_InstanceIds(self): # String
 		return self.get_query_params().get('InstanceIds')
 
-	def set_InstanceIds(self,InstanceIds):
-		self.add_query_param('InstanceIds',InstanceIds)
\ No newline at end of file
+	def set_InstanceIds(self, InstanceIds):  # String
+		self.add_query_param('InstanceIds', InstanceIds)
