@@ -25,20 +25,18 @@ class DescribeProjectMetaRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeProjectMeta','cms')
 		self.set_method('POST')
 
-	def get_PageSize(self):
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_PageNumber(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_Labels(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_Labels(self): # String
 		return self.get_query_params().get('Labels')
 
-	def set_Labels(self,Labels):
-		self.add_query_param('Labels',Labels)
\ No newline at end of file
+	def set_Labels(self, Labels):  # String
+		self.add_query_param('Labels', Labels)
