@@ -25,20 +25,18 @@ class DescribeTagValueListRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeTagValueList','cms')
 		self.set_method('POST')
 
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_PageSize(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_TagKey(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_TagKey(self): # String
 		return self.get_query_params().get('TagKey')
 
-	def set_TagKey(self,TagKey):
-		self.add_query_param('TagKey',TagKey)
\ No newline at end of file
+	def set_TagKey(self, TagKey):  # String
+		self.add_query_param('TagKey', TagKey)
