@@ -25,10 +25,9 @@ class EnableEventRulesRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'EnableEventRules','cms')
 		self.set_method('POST')
 
-	def get_RuleNamess(self):
-		return self.get_query_params().get('RuleNamess')
+	def get_RuleNamess(self): # RepeatList
+		return self.get_query_params().get('RuleNames')
 
-	def set_RuleNamess(self, RuleNamess):
-		for depth1 in range(len(RuleNamess)):
-			if RuleNamess[depth1] is not None:
-				self.add_query_param('RuleNames.' + str(depth1 + 1) , RuleNamess[depth1])
\ No newline at end of file
+	def set_RuleNamess(self, RuleNames):  # RepeatList
+		for depth1 in range(len(RuleNames)):
+			self.add_query_param('RuleNames.' + str(depth1 + 1), RuleNames[depth1])
