@@ -25,8 +25,8 @@ class UninstallMonitoringAgentRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'UninstallMonitoringAgent','cms')
 		self.set_method('POST')
 
-	def get_InstanceId(self):
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
